==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/GeopsyGui/src/PickItem.h <==
/***************************************************************************
**
**  This file is part of GeopsyGui.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2007-03-30
**  Copyright: 2007-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef PICKITEM_H
#define PICKITEM_H

#include "GeopsyGuiDLLExport.h"
#include "PicksProperties.h"

namespace GeopsyGui {

class GEOPSYGUI_EXPORT PickItem : public QAbstractTableModel
{
public:
  PickItem(PicksProperties * picks);

  virtual int rowCount(const QModelIndex &parent=QModelIndex()) const;
  virtual int columnCount(const QModelIndex &parent=QModelIndex()) const;
  virtual QVariant data(const QModelIndex &index, int role) const;
  virtual QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const;
  virtual bool setData(const QModelIndex & index, const QVariant & value, int role=Qt::EditRole);
  virtual Qt::ItemFlags flags (const QModelIndex & index) const;

  void beginPickChange() {beginResetModel();}
  void endPickChange() {endResetModel();}
private:
  PicksProperties * _picks;
};

} // namespace GeopsyGui

#endif // PICKITEM_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/GeopsyGui/src/PickItem.h <==
/***************************************************************************
**
**  This file is part of GeopsyGui.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2007-03-30
**  Copyright: 2007-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef PICKITEM_H
#define PICKITEM_H

#include "GeopsyGuiDLLExport.h"
#include "PicksProperties.h"

namespace GeopsyGui {

#define PICKITEM_ATTRIBUTE_COUNT 3
#define PICKITEM_ATTRIBUTE_NAME 0
#define PICKITEM_ATTRIBUTE_VISIBLE 1
#define PICKITEM_ATTRIBUTE_COLOR 2

  class GEOPSYGUI_EXPORT PickItem : public QAbstractTableModel
  {
  public:
    PickItem(PicksProperties * picks);

    int rowCount(const QModelIndex &parent=QModelIndex()) const;
    int columnCount(const QModelIndex &parent=QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const;
    bool setData(const QModelIndex & index, const QVariant & value, int role=Qt::EditRole);
    Qt::ItemFlags flags (const QModelIndex & index) const;

    void beginPickChange() {beginResetModel();}
    void endPickChange() {endResetModel();}
  private:
    PicksProperties * _picks;
  };

} // namespace GeopsyGui

#endif // PICKITEM_H
